Struct orchestrator::orchestrator::OrchestratorReference
source · pub struct OrchestratorReference<S: ExecutorGlobalState> { /* private fields */ }Expand description
A shared reference to the orchestrator
Methods from Deref<Target = Orchestrator<S>>
sourcepub async fn process_exercise(
&self,
name: String,
source: String,
user: User<Authenticated>,
) -> Result<ExerciseResult, DynError>
pub async fn process_exercise( &self, name: String, source: String, user: User<Authenticated>, ) -> Result<ExerciseResult, DynError>
process the given exercise (name), and deliver the source (s). it gives back an ExerciseResult if all is gone well
sourcepub async fn add_exercise<ExerciseType: ExerciseDef + ExecutorState>(
&self,
name: &str,
source: &str,
) -> Result<(), DynError>
pub async fn add_exercise<ExerciseType: ExerciseDef + ExecutorState>( &self, name: &str, source: &str, ) -> Result<(), DynError>
add exercise, Then tries to do a normal execution, and check if it does indeed return full score if not returns an error (and obviusly doesn’t add it)
pub async fn get_exercise_info( &self, name: String, ) -> Result<Box<dyn ExerciseDef>, DynError>